[![codecov](https://codecov.io/gh/justgigio/awesome-git-mosaic/graph/badge.svg?token=0ON0YL8EAH)](https://codecov.io/gh/justgigio/awesome-git-mosaic)
![build](https://github.com/justgigio/awesome-git-mosaic/actions/workflows/build.yml/badge.svg)
- Pypi badge
- python version badge
- docs badge
# awesome-git-mosaic
A simple tool to make cool tricks with your GitHub activity mosaic
